# aws-ami-delete

[![Build Status](https://travis-ci.org/lifeofguenter/aws-ami-delete.svg?branch=master)](https://travis-ci.org/lifeofguenter/aws-ami-delete)
[![PyPI](https://img.shields.io/pypi/v/aws-ami-delete.svg)](https://pypi.org/project/aws-ami-delete/)
[![License](https://img.shields.io/github/license/lifeofguenter/aws-ami-delete.svg)](LICENSE)
